# pangaea
An xarray extension for land surface models.

[![License (3-Clause BSD)](https://img.shields.io/badge/license-BSD%203--Clause-yellow.svg)](https://github.com/snowman2/pangeaea/blob/master/LICENSE)

[![Build Status](https://travis-ci.org/snowman2/pangaea.svg?branch=master)](https://travis-ci.org/snowman2/pangaea)

[![Build status](https://ci.appveyor.com/api/projects/status/aa0tcguo4iqw7aa6/branch/master?svg=true)](https://ci.appveyor.com/project/snowman2/pangaea/branch/master)

[![Coverage Status](https://coveralls.io/repos/github/snowman2/pangaea/badge.svg?branch=master)](https://coveralls.io/github/snowman2/pangaea?branch=master)

[![Documentation Status](https://readthedocs.org/projects/pangaea/badge/?version=latest)](http://pangaea.readthedocs.io/en/latest/?badge=latest)
